%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Maximum Likelihood Estimation of QRE in the Monotone Game Experiments   %
% Choi,Gale,and Kariv (2007), "Sequential Equilibrium in Monotone Games:  %
%              Theory-Based Analysis of Experimental Data"                %
%                                                                         %
% Number of Players in a Group (N): 3                                     %
% Length of Time Period (T): 5                                            %
% Endowment (E) for Each Player: 1                                        %
% Cost of Public Good (K): 2                                              %
%                                                                         %
% Value of Public Good (A): either 1.5 or 3                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc

load Data_T5_A15.mat
load Data_T5_A3.mat

% Load two data files (A = 3 and A = 1.5) in the workspace
% Each data file contains separately 9 subfiles, whose titles are
% of the form 'a_tn_A', contains a set of binary variables at two states
% (t,n) in the treatment with A. 

% t: the time period when actions are chosen
% n: the number of total contribution up to time period t
% Action: (0 == no contribution) and (1 == contribution)

load Raw_T5_A15.mat
load Raw_T5_A3.mat

% Load original raw data, which are used in computing SEs using a Bootstrap method

options = optimset('Display','iter');

xbeta0 = [2.8647;3.3513;2.6985;8.9492;3.3746;2.4547;0.36734;3.4323;1.7322;0.56685;0.98784;-0.86427;0.855];

%xbeta0 = [3;3;0.5;-1;2;-5;-3;1;1;3;-4;-3;4]; % initial starting point of beta = exp(xbeta0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Obtain MLE of QRE with the unrestricted beta specification when A = 1.5
% Beta: the sensitivity parameter in logistic functional form
% For detailed illustrations of MLE, refer to Choi, Gale, and Kariv (2007)

[xbeta_15,fval_15] = fminsearch(@lolik,xbeta0,options,a10_15,a20_15,a21_15,a22_15,a30_15,a31_15,a32_15,a40_15,a41_15,a42_15,a50_15,a51_15,a52_15,1.5)

% A Nelder-Mead (1965) Simplex method for MLE

beta_15 = exp(xbeta_15); % ML Estimate of Beta
loglik_15 = - fval_15; % Log-likelihood value at MLE

EU_15 = lolik_EU(xbeta_15,a10_15,a20_15,a21_15,a22_15,a30_15,a31_15,a32_15,a40_15,a41_15,a42_15,a50_15,a51_15,a52_15,1.5);

% Payoff differences between contribution and no contribution at each (t,n)
% and their corresponding choice probabilities

SE_15 = bstrap_unrestricted(Raw_T5_A15,100,1.5);

% Standard error of Beta estimate that is computed using a bootstrap method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save beta_15 beta_15
save loglik_15 loglik_15
save EU_15 EU_15
save SE_15 SE_15

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Obtain MLE of QRE with the unrestricted beta specification when A = 3

xbeta0 = [2.6933;2.5225;2.8977;2.0459;2.2628;3.6926;0.26603;4.744;10.69;0.86604;-2.239;0.97219;0.96937];

[xbeta_3,fval_3] = fminsearch(@lolik,xbeta0,options,a10_3,a20_3,a21_3,a22_3,a30_3,a31_3,a32_3,a40_3,a41_3,a42_3,a50_3,a51_3,a52_3,3)

% A Nelder-Mead (1965) Simplex method for MLE

beta_3 = exp(xbeta_3); % ML Estimate of Beta
loglik_3 = - fval_3; % Log-likelihood value at MLE

EU_3 = lolik_EU(xbeta_3,a10_3,a20_3,a21_3,a22_3,a30_3,a31_3,a32_3,a40_3,a41_3,a42_3,a50_3,a51_3,a52_3,3);

% Payoff differences between contribution and no contribution at each (t,n)

SE_3 = bstrap_unrestricted(Raw_T5_A3,100,3);

% Standard error of Beta estimate that is computed using a bootstrap method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save beta_3 beta_3
save loglik_3 loglik_3
save EU_3 EU_3
save SE_3 SE_3











