%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% Computing standard errors for model parameters using a bootstrap method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function output = bstrap_unrestricted(data,nsp,A)

% data: we use original raw data for bootstrap resampling

[n1,n2] = size(data);

n = n1/3;

unif = n*rand(nsp,n); tbeta = []; t1 = 0;

for i1 = 1:nsp
%%%%%%%% Resampling %%%%%%%%%%        
    rsam = unif(i1,:);
    
    rdt = [];

    for j = 1:n
        for k = 1:n
            if (((k-1) <= rsam(j))&(rsam(j) < k))
                m1 = 3*(k-1)+1; m2 = 3*k;
                rdt = [rdt;data(m1:m2,3:7)];    
            end
        end
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%% Sorting data according to states %%%%%%%%%%%%%%%%    
    dt = rdt;

    d10 = []; d20 = []; d21 = []; d22 = []; d30 = []; d31 = []; d32 = [];
    d40 = []; d41 = []; d42 = []; d50 = []; d51 = []; d52 = [];

    for i = 1:n
    
        m1 = 3*(i-1)+1; m2 = 3*i;
    
        round1 = dt(m1:m2,:); round = ones(3,5);
    
        for j = 1:3
            for k = 1:5    
                if (round1(j,k) == -1)
                    round(j,k) = 0;                
                end
            end
        end
    
        s2 = sum(round(:,1)); s3 = sum(round(:,2)); s4 = sum(round(:,3)); s5 = sum(round(:,4));

        for j = 1:3
            d10 = [d10;round(j,1)];    
        end
    
        if (s2 == 0)
            for j = 1:3
                d20 = [d20;round(j,2)];    
            end
        elseif (s2 == 1)
            for j = 1:3
                if (round(j,1) == 0)
                    d21 = [d21;round(j,2)];
                end
            end
        elseif (s2 == 2)
            for j = 1:3
                if (round(j,1) == 0)
                    d22 = [d22;round(j,2)];
                end
            end        
        end
    
        if (s3 == 0)
            for j = 1:3
                d30 = [d30;round(j,3)];    
            end
        elseif (s3 == 1)
            for j = 1:3
                if (round(j,2) == 0)
                    d31 = [d31;round(j,3)];
                end
            end
        elseif (s3 == 2)
            for j = 1:3
                if (round(j,2) == 0)
                    d32 = [d32;round(j,3)];
                end
            end        
        end
    
        if (s4 == 0)
            for j = 1:3
                d40 = [d40;round(j,4)];    
            end
        elseif (s4 == 1)
            for j = 1:3
                if (round(j,3) == 0)
                    d41 = [d41;round(j,4)];
                end
            end
        elseif (s4 == 2)
            for j = 1:3
                if (round(j,3) == 0)
                    d42 = [d42;round(j,4)];
                end
            end        
        end
    
        if (s5 == 0)
            for j = 1:3
                d50 = [d50;round(j,5)];    
            end
        elseif (s5 == 1)
            for j = 1:3
                if (round(j,4) == 0)
                    d51 = [d51;round(j,5)];
                end
            end
        elseif (s5 == 2)
            for j = 1:3
                if (round(j,4) == 0)
                    d52 = [d52;round(j,5)];
                end
            end        
        end
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    z1 = length(d22); z2 = length(d32); z3 = length(d42);
%%%%%%%%%%%%%%%%%% Estimation with resampled data %%%%%%%%%%%%%%
% The resampled data is used if there are samples at all states 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if ((z1 >= 1)&(z2 >= 1)&(z3 >= 1))
        
        %t1 = t1 + 1
    
        options = optimset('Display','off');
        for i = 1:2
            if (i == 1)
                if (A == 3)
                    xbeta0 = [2.6933;2.5225;2.8977;2.0459;2.2628;3.6926;0.26603;4.744;10.69;0.86604;-2.239;0.97219;0.96937]; % initial starting point of beta = exp(xbeta0)
                elseif (A == 1.5)
                    xbeta0 = [2.8647;3.3513;2.6985;8.9492;3.3746;2.4547;0.36734;3.4323;1.7322;0.56685;0.98784;-0.86427;0.855];
                end
    
                [xbeta1,fval1] = fminsearch(@lolik,xbeta0,options,d10,d20,d21,d22,d30,d31,d32,d40,d41,d42,d50,d51,d52,A);
            else
                if (A == 3)
                    xbeta0 = zeros(13,1);
                elseif (A == 1.5)
                    xbeta0 = zeros(13,1);
                end
    
                [xbeta2,fval2] = fminsearch(@lolik,xbeta0,options,d10,d20,d21,d22,d30,d31,d32,d40,d41,d42,d50,d51,d52,A);
            end
        end
        % A Nelder-Mead (1965) Simplex method for MLE
        if (fval2 <= fval1)
            beta = exp(xbeta2); % ML Estimate of Beta
        else
            beta = exp(xbeta1); % ML Estimate of Beta
        end
                
        iden = zeros(13,1);
        
        if ((isnan(beta) == iden)&(isinf(beta) == iden))
        
            tbeta = [tbeta;beta'];
            
        end
    
    end 
end

output = std(tbeta);




